@@ -45,6 +45,8 @@ OC.L10N.register(
     "Close" : "বন্ধ",
     "Date" : "Date",
     "Tags" : "ট্যাগ",
+    "Help" : "সহায়িকা",
+    "Actions" : "পদক্ষেপসমূহ",
     "delete" : "মুছে ফেল",
     "Edit" : "সম্পাদনা",
     "Reset" : "পূণঃনির্ধানণ",
