@@ -11,27 +11,39 @@ OC.L10N.register(
     "None" : "Ništa",
     "SMTP Password" : "SMPT Lozinka",
     "Cancel" : "Otkaži",
+    "Accounts" : "Accounts",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Delete" : "Obriši",
     "Search" : "Search",
     "Send" : "Pošalji",
+    "Ok" : "Ok",
     "Choose" : "Izaberite",
     "Favorite" : "Favorit",
     "Edit tags" : "Izmjeni oznake",
+    "Attendees" : "Sudionici",
     "Description" : "Opis",
     "Create" : "Ustvari",
     "Select" : "Select",
     "Comment" : "Komentar",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
+    "Today" : "Danas",
     "Other" : "Ostali",
     "Move" : "Move",
-    "Quota" : "Kvota",
     "Rename" : "Preimenuj",
     "Add" : "Dodaj",
     "Close" : "Zatvori",
     "Date" : "Date",
     "Tag already exists" : "Oznaka već postoji",
+    "Help" : "Pomoć",
+    "Actions" : "Radnje",
+    "delete" : "izbriši",
+    "Edit" : "Izmjeni",
+    "User" : "User",
+    "Port" : "Priključak",
+    "Valid until" : "Validno do",
+    "Group" : "Grupa",
+    "Shared" : "Podijeljen",
     "All" : "Sve",
     "Favorites" : "Favoriti"
 },
