@@ -103,7 +103,9 @@ OC.L10N.register(
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
     "Recipient" : "Destinatario",
+    "Help" : "Ayuda",
     "matches" : "coincide",
+    "Actions" : "Acciones",
     "Priority" : "Prioridad",
     "delete" : "borrar",
     "Edit" : "Editar",
