@@ -20,32 +20,39 @@ OC.L10N.register(
     "Search" : "Nadi",
     "Send" : "Tuzna",
     "Refresh" : "Sismeḍ",
+    "Ok" : "Ih",
     "Choose" : "Fren",
     "Confirm" : "Serggeg",
     "Favorite" : "Menyif",
+    "Read" : "Taɣuri",
     "More actions" : "Ugar n tigawin",
     "Back" : "Retour",
     "Mark as unread" : "Creḍ ur yettwaɣra ara",
     "Mark as read" : "Creḍ yettwaɣra",
+    "Description" : "Aglam",
     "Create" : "Snulfu-d",
     "Select" : "Fren",
     "Comment" : "Commentaire",
     "Remove" : "Kkes",
     "Today" : "Ass-a",
+    "Yesterday" : "Iḍelli",
     "Other" : "Wayeḍ",
     "Forward" : "Avancer",
     "Translate" : "Suqel",
     "Move" : "Senkez",
     "Remove account" : "Kkes amiḍan",
+    "Add folder" : "Rnu akaram",
     "Folder name" : "Isem n ukaram",
     "Loading …" : "Asali ...",
     "Delete folder" : "Kkes akaram",
     "Rename" : "Beddel isem",
+    "Draft" : "Arewway",
     "Reply" : "Err",
     "Retry" : "Ɛreḍ tikkelt-nniḍen",
     "Message" : "Izen",
-    "Copy to clipboard" : "Copier dans le presse-papiers",
+    "Copy to clipboard" : "Nɣel-it ar tecfawit",
     "Add" : "Rnu",
+    "Clear" : "Ṣfeḍ",
     "Close" : "Mdel",
     "Date" : "Azemz",
     "Tags" : "Tibzimin",
