@@ -43,7 +43,9 @@ OC.L10N.register(
     "Date" : "Dato",
     "Tags" : "Emneord",
     "Recipient" : "Mottakar",
+    "Help" : "Hjelp",
     "contains" : "inneheld",
+    "Actions" : "Handlingar",
     "delete" : "slett",
     "Edit" : "Rediger",
     "Client ID" : "Klient-ID",
